@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"time"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/cli/cli/v2/internal/codespaces"
@@ -12,10 +13,11 @@ import (
 )
 
 type createOptions struct {
-	repo       string
-	branch     string
-	machine    string
-	showStatus bool
+	repo        string
+	branch      string
+	machine     string
+	showStatus  bool
+	idleTimeout time.Duration
 }
 
 func newCreateCmd(app *App) *cobra.Command {
@@ -34,6 +36,7 @@ func newCreateCmd(app *App) *cobra.Command {
 	createCmd.Flags().StringVarP(&opts.branch, "branch", "b", "", "repository branch")
 	createCmd.Flags().StringVarP(&opts.machine, "machine", "m", "", "hardware specifications for the VM")
 	createCmd.Flags().BoolVarP(&opts.showStatus, "status", "s", false, "show status of post-create command and dotfiles")
+	createCmd.Flags().DurationVar(&opts.idleTimeout, "idle-timeout", 0, "allowed inactivity before codespace is stopped, e.g. \"10m\", \"1h\"")
 
 	return createCmd
 }
@@ -57,8 +60,14 @@ func (a *App) Create(ctx context.Context, opts createOptions) error {
 		}
 		questions := []*survey.Question{
 			{
-				Name:     "repository",
-				Prompt:   &survey.Input{Message: "Repository:"},
+				Name: "repository",
+				Prompt: &survey.Input{
+					Message: "Repository:",
+					Help:    "Search for repos by name. To search within an org or user, or to see private repos, enter at least ':user/'.",
+					Suggest: func(toComplete string) []string {
+						return getRepoSuggestions(ctx, a.apiClient, toComplete)
+					},
+				},
 				Validate: survey.Required,
 			},
 			{
@@ -101,10 +110,11 @@ func (a *App) Create(ctx context.Context, opts createOptions) error {
 
 	a.StartProgressIndicatorWithLabel("Creating codespace")
 	codespace, err := a.apiClient.CreateCodespace(ctx, &api.CreateCodespaceParams{
-		RepositoryID: repository.ID,
-		Branch:       branch,
-		Machine:      machine,
-		Location:     locationResult.Location,
+		RepositoryID:       repository.ID,
+		Branch:             branch,
+		Machine:            machine,
+		Location:           locationResult.Location,
+		IdleTimeoutMinutes: int(opts.idleTimeout.Minutes()),
 	})
 	a.StopProgressIndicator()
 	if err != nil {
@@ -234,7 +244,7 @@ func getMachineName(ctx context.Context, apiClient apiClient, repoID int, machin
 	machineNames := make([]string, 0, len(machines))
 	machineByName := make(map[string]*api.Machine)
 	for _, m := range machines {
-		machineName := m.DisplayName
+		machineName := buildDisplayName(m.DisplayName, m.PrebuildAvailability)
 		machineNames = append(machineNames, machineName)
 		machineByName[machineName] = m
 	}
@@ -260,3 +270,29 @@ func getMachineName(ctx context.Context, apiClient apiClient, repoID int, machin
 
 	return selectedMachine.Name, nil
 }
+
+func getRepoSuggestions(ctx context.Context, apiClient apiClient, partialSearch string) []string {
+	searchParams := api.RepoSearchParameters{
+		// The prompt shows 7 items so 7 effectively turns off scrolling which is similar behavior to other clients
+		MaxRepos: 7,
+		Sort:     "repo",
+	}
+
+	repos, err := apiClient.GetCodespaceRepoSuggestions(ctx, partialSearch, searchParams)
+	if err != nil {
+		return nil
+	}
+
+	return repos
+}
+
+// buildDisplayName returns display name to be used in the machine survey prompt.
+func buildDisplayName(displayName string, prebuildAvailability string) string {
+	prebuildText := ""
+
+	if prebuildAvailability == "blob" || prebuildAvailability == "pool" {
+		prebuildText = " (Prebuild ready)"
+	}
+
+	return fmt.Sprintf("%s%s", displayName, prebuildText)
+}
