@@ -13,16 +13,22 @@ import (
 	"github.com/cli/cli/v2/internal/ghrepo"
 	"github.com/cli/cli/v2/pkg/githubtemplate"
 	"github.com/cli/cli/v2/pkg/prompt"
+	graphql "github.com/cli/shurcooL-graphql"
 	"github.com/shurcooL/githubv4"
-	"github.com/shurcooL/graphql"
 )
 
 type issueTemplate struct {
-	// I would have un-exported these fields, except `shurcool/graphql` then cannot unmarshal them :/
+	// I would have un-exported these fields, except `cli/shurcool-graphql` then cannot unmarshal them :/
 	Gname string `graphql:"name"`
 	Gbody string `graphql:"body"`
 }
 
+type pullRequestTemplate struct {
+	// I would have un-exported these fields, except `cli/shurcool-graphql` then cannot unmarshal them :/
+	Gname string `graphql:"filename"`
+	Gbody string `graphql:"body"`
+}
+
 func (t *issueTemplate) Name() string {
 	return t.Gname
 }
@@ -35,7 +41,19 @@ func (t *issueTemplate) Body() []byte {
 	return []byte(t.Gbody)
 }
 
-func listIssueTemplates(httpClient *http.Client, repo ghrepo.Interface) ([]issueTemplate, error) {
+func (t *pullRequestTemplate) Name() string {
+	return t.Gname
+}
+
+func (t *pullRequestTemplate) NameForSubmit() string {
+	return ""
+}
+
+func (t *pullRequestTemplate) Body() []byte {
+	return []byte(t.Gbody)
+}
+
+func listIssueTemplates(httpClient *http.Client, repo ghrepo.Interface) ([]Template, error) {
 	var query struct {
 		Repository struct {
 			IssueTemplates []issueTemplate
@@ -54,10 +72,44 @@ func listIssueTemplates(httpClient *http.Client, repo ghrepo.Interface) ([]issue
 		return nil, err
 	}
 
-	return query.Repository.IssueTemplates, nil
+	ts := query.Repository.IssueTemplates
+	templates := make([]Template, len(ts))
+	for i := range templates {
+		templates[i] = &ts[i]
+	}
+
+	return templates, nil
 }
 
-func hasIssueTemplateSupport(httpClient *http.Client, hostname string) (bool, error) {
+func listPullRequestTemplates(httpClient *http.Client, repo ghrepo.Interface) ([]Template, error) {
+	var query struct {
+		Repository struct {
+			PullRequestTemplates []pullRequestTemplate
+		} `graphql:"repository(owner: $owner, name: $name)"`
+	}
+
+	variables := map[string]interface{}{
+		"owner": githubv4.String(repo.RepoOwner()),
+		"name":  githubv4.String(repo.RepoName()),
+	}
+
+	gql := graphql.NewClient(ghinstance.GraphQLEndpoint(repo.RepoHost()), httpClient)
+
+	err := gql.QueryNamed(context.Background(), "PullRequestTemplates", &query, variables)
+	if err != nil {
+		return nil, err
+	}
+
+	ts := query.Repository.PullRequestTemplates
+	templates := make([]Template, len(ts))
+	for i := range templates {
+		templates[i] = &ts[i]
+	}
+
+	return templates, nil
+}
+
+func hasTemplateSupport(httpClient *http.Client, hostname string, isPR bool) (bool, error) {
 	if !ghinstance.IsEnterprise(hostname) {
 		return true, nil
 	}
@@ -81,20 +133,29 @@ func hasIssueTemplateSupport(httpClient *http.Client, hostname string) (bool, er
 		return false, err
 	}
 
-	var hasQuerySupport bool
-	var hasMutationSupport bool
+	var hasIssueQuerySupport bool
+	var hasIssueMutationSupport bool
+	var hasPullRequestQuerySupport bool
+
 	for _, field := range featureDetection.Repository.Fields {
 		if field.Name == "issueTemplates" {
-			hasQuerySupport = true
+			hasIssueQuerySupport = true
+		}
+		if field.Name == "pullRequestTemplates" {
+			hasPullRequestQuerySupport = true
 		}
 	}
 	for _, field := range featureDetection.CreateIssueInput.InputFields {
 		if field.Name == "issueTemplate" {
-			hasMutationSupport = true
+			hasIssueMutationSupport = true
 		}
 	}
 
-	return hasQuerySupport && hasMutationSupport, nil
+	if isPR {
+		return hasPullRequestQuerySupport, nil
+	} else {
+		return hasIssueQuerySupport && hasIssueMutationSupport, nil
+	}
 }
 
 type Template interface {
@@ -129,13 +190,10 @@ func NewTemplateManager(httpClient *http.Client, repo ghrepo.Interface, dir stri
 }
 
 func (m *templateManager) hasAPI() (bool, error) {
-	if m.isPR {
-		return false, nil
-	}
 	if m.cachedClient == nil {
 		m.cachedClient = api.NewCachedClient(m.httpClient, time.Hour*24)
 	}
-	return hasIssueTemplateSupport(m.cachedClient, m.repo.RepoHost())
+	return hasTemplateSupport(m.cachedClient, m.repo.RepoHost(), m.isPR)
 }
 
 func (m *templateManager) HasTemplates() (bool, error) {
@@ -201,14 +259,15 @@ func (m *templateManager) fetch() error {
 	}
 
 	if hasAPI {
-		issueTemplates, err := listIssueTemplates(m.httpClient, m.repo)
+		lister := listIssueTemplates
+		if m.isPR {
+			lister = listPullRequestTemplates
+		}
+		templates, err := lister(m.httpClient, m.repo)
 		if err != nil {
 			return err
 		}
-		m.templates = make([]Template, len(issueTemplates))
-		for i := range issueTemplates {
-			m.templates[i] = &issueTemplates[i]
-		}
+		m.templates = templates
 	}
 
 	if !m.allowFS {
