@@ -1,13 +1,14 @@
 package release
 
 import (
-	cmdCreate "github.com/cli/cli/pkg/cmd/release/create"
-	cmdDelete "github.com/cli/cli/pkg/cmd/release/delete"
-	cmdDownload "github.com/cli/cli/pkg/cmd/release/download"
-	cmdList "github.com/cli/cli/pkg/cmd/release/list"
-	cmdUpload "github.com/cli/cli/pkg/cmd/release/upload"
-	cmdView "github.com/cli/cli/pkg/cmd/release/view"
-	"github.com/cli/cli/pkg/cmdutil"
+	cmdCreate "github.com/cli/cli/v2/pkg/cmd/release/create"
+	cmdDelete "github.com/cli/cli/v2/pkg/cmd/release/delete"
+	cmdDeleteAsset "github.com/cli/cli/v2/pkg/cmd/release/delete-asset"
+	cmdDownload "github.com/cli/cli/v2/pkg/cmd/release/download"
+	cmdList "github.com/cli/cli/v2/pkg/cmd/release/list"
+	cmdUpload "github.com/cli/cli/v2/pkg/cmd/release/upload"
+	cmdView "github.com/cli/cli/v2/pkg/cmd/release/view"
+	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/spf13/cobra"
 )
 
@@ -24,6 +25,7 @@ func NewCmdRelease(f *cmdutil.Factory) *cobra.Command {
 
 	cmd.AddCommand(cmdCreate.NewCmdCreate(f, nil))
 	cmd.AddCommand(cmdDelete.NewCmdDelete(f, nil))
+	cmd.AddCommand(cmdDeleteAsset.NewCmdDeleteAsset(f, nil))
 	cmd.AddCommand(cmdDownload.NewCmdDownload(f, nil))
 	cmd.AddCommand(cmdList.NewCmdList(f, nil))
 	cmd.AddCommand(cmdView.NewCmdView(f, nil))
