@@ -2,6 +2,7 @@ package root
 
 import (
 	"github.com/MakeNowJust/heredoc"
+	"github.com/cli/cli/v2/pkg/text"
 	"github.com/spf13/cobra"
 )
 
@@ -10,7 +11,7 @@ var HelpTopics = map[string]map[string]string{
 		"short": "Information about using gh with MinTTY",
 		"long": heredoc.Doc(`
 			MinTTY is the terminal emulator that comes by default with Git
-			for Windows.  It has known issues with gh's ability to prompt a
+			for Windows. It has known issues with gh's ability to prompt a
 			user for input.
 
 			There are a few workarounds to make gh work with MinTTY:
@@ -53,7 +54,7 @@ var HelpTopics = map[string]map[string]string{
 			to, e.g. "less".
 
 			GLAMOUR_STYLE: the style to use for rendering Markdown. See
-			https://github.com/charmbracelet/glamour#styles
+			<https://github.com/charmbracelet/glamour#styles>
 
 			NO_COLOR: set to any value to avoid printing ANSI escape sequences for color output.
 
@@ -89,14 +90,14 @@ var HelpTopics = map[string]map[string]string{
 			The %[1]s--jq%[1]s option accepts a query in jq syntax and will print only the resulting
 			values that match the query. This is equivalent to piping the output to %[1]sjq -r%[1]s,
 			but does not require the jq utility to be installed on the system. To learn more
-			about the query syntax, see: https://stedolan.github.io/jq/manual/v1.6/
+			about the query syntax, see: <https://stedolan.github.io/jq/manual/v1.6/>
 
 			With %[1]s--template%[1]s, the provided Go template is rendered using the JSON data as input.
-			For the syntax of Go templates, see: https://golang.org/pkg/text/template/
+			For the syntax of Go templates, see: <https://golang.org/pkg/text/template/>
 
 			The following functions are available in templates:
 			- %[1]sautocolor%[1]s: like %[1]scolor%[1]s, but only emits color to terminals
-			- %[1]scolor <style> <input>%[1]s: colorize input using https://github.com/mgutz/ansi
+			- %[1]scolor <style> <input>%[1]s: colorize input using <https://github.com/mgutz/ansi>
 			- %[1]sjoin <sep> <list>%[1]s: joins values in the list using a separator
 			- %[1]spluck <field> <list>%[1]s: collects values of a field from all items in the input
 			- %[1]stablerow <fields>...%[1]s: aligns fields in output vertically as a table
@@ -104,31 +105,32 @@ var HelpTopics = map[string]map[string]string{
 			- %[1]stimeago <time>%[1]s: renders a timestamp as relative to now
 			- %[1]stimefmt <format> <time>%[1]s: formats a timestamp using Go's Time.Format function
 			- %[1]struncate <length> <input>%[1]s: ensures input fits within length
-
-			EXAMPLES
-			  # format issues as table
-			  $ gh issue list --json number,title --template \
-			    '{{range .}}{{tablerow (printf "#%%v" .number | autocolor "green") .title}}{{end}}'
-			
-			  # format a pull request using multiple tables with headers
-			  $ gh pr view 3519 --json number,title,body,reviews,assignees --template \
-			    '{{printf "#%%v" .number}} {{.title}}
-
-			    {{.body}}
-
-			    {{tablerow "ASSIGNEE" "NAME"}}{{range .assignees}}{{tablerow .login .name}}{{end}}{{tablerender}}
-			    {{tablerow "REVIEWER" "STATE" "COMMENT"}}{{range .reviews}}{{tablerow .author.login .state .body}}{{end}}
-			    '
 		`, "`"),
+		"example": heredoc.Doc(`
+			# format issues as table
+			$ gh issue list --json number,title --template \
+			  '{{range .}}{{tablerow (printf "#%v" .number | autocolor "green") .title}}{{end}}'
+
+			# format a pull request using multiple tables with headers
+			$ gh pr view 3519 --json number,title,body,reviews,assignees --template \
+			  '{{printf "#%v" .number}} {{.title}}
+
+			  {{.body}}
+
+			  {{tablerow "ASSIGNEE" "NAME"}}{{range .assignees}}{{tablerow .login .name}}{{end}}{{tablerender}}
+			  {{tablerow "REVIEWER" "STATE" "COMMENT"}}{{range .reviews}}{{tablerow .author.login .state .body}}{{end}}
+			  '
+		`),
 	},
 }
 
 func NewHelpTopic(topic string) *cobra.Command {
 	cmd := &cobra.Command{
-		Use:    topic,
-		Short:  HelpTopics[topic]["short"],
-		Long:   HelpTopics[topic]["long"],
-		Hidden: true,
+		Use:     topic,
+		Short:   HelpTopics[topic]["short"],
+		Long:    HelpTopics[topic]["long"],
+		Example: HelpTopics[topic]["example"],
+		Hidden:  true,
 		Annotations: map[string]string{
 			"markdown:generate": "true",
 			"markdown:basename": "gh_help_" + topic,
@@ -143,6 +145,10 @@ func NewHelpTopic(topic string) *cobra.Command {
 
 func helpTopicHelpFunc(command *cobra.Command, args []string) {
 	command.Print(command.Long)
+	if command.Example != "" {
+		command.Printf("\n\nEXAMPLES\n")
+		command.Print(text.Indent(command.Example, "  "))
+	}
 }
 
 func helpTopicUsageFunc(command *cobra.Command) error {
