@@ -1,11 +1,14 @@
 package set
 
 import (
+	"bytes"
 	"encoding/base64"
 	"fmt"
 	"io"
 	"io/ioutil"
 	"net/http"
+	"os"
+	"strings"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc"
@@ -16,6 +19,8 @@ import (
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/prompt"
+	"github.com/hashicorp/go-multierror"
+	"github.com/joho/godotenv"
 	"github.com/spf13/cobra"
 	"golang.org/x/crypto/nacl/box"
 )
@@ -26,7 +31,7 @@ type SetOptions struct {
 	Config     func() (config.Config, error)
 	BaseRepo   func() (ghrepo.Interface, error)
 
-	RandomOverride io.Reader
+	RandomOverride func() io.Reader
 
 	SecretName      string
 	OrgName         string
@@ -36,6 +41,7 @@ type SetOptions struct {
 	DoNotStore      bool
 	Visibility      string
 	RepositoryNames []string
+	EnvFile         string
 }
 
 func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command {
@@ -81,6 +87,9 @@ func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command
 
 			# Set user-level secret for Codespaces
 			$ gh secret set MYSECRET --user
+
+			# Set multiple secrets imported from the ".env" file
+			$ gh secret set -f .env
 		`),
 		Args: cobra.MaximumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -91,8 +100,16 @@ func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command
 				return err
 			}
 
+			if err := cmdutil.MutuallyExclusive("specify only one of `--body` or `--env-file`", opts.Body != "", opts.EnvFile != ""); err != nil {
+				return err
+			}
+
+			if err := cmdutil.MutuallyExclusive("specify only one of `--env-file` or `--no-store`", opts.EnvFile != "", opts.DoNotStore); err != nil {
+				return err
+			}
+
 			if len(args) == 0 {
-				if !opts.DoNotStore {
+				if !opts.DoNotStore && opts.EnvFile == "" {
 					return cmdutil.FlagErrorf("must pass name argument")
 				}
 			} else {
@@ -136,14 +153,15 @@ func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command
 	cmd.Flags().StringSliceVarP(&opts.RepositoryNames, "repos", "r", []string{}, "List of `repositories` that can access an organization or user secret")
 	cmd.Flags().StringVarP(&opts.Body, "body", "b", "", "The value for the secret (reads from standard input if not specified)")
 	cmd.Flags().BoolVar(&opts.DoNotStore, "no-store", false, "Print the encrypted, base64-encoded value instead of storing it on Github")
+	cmd.Flags().StringVarP(&opts.EnvFile, "env-file", "f", "", "Load secret names and values from a dotenv-formatted `file`")
 
 	return cmd
 }
 
 func setRun(opts *SetOptions) error {
-	body, err := getBody(opts)
+	secrets, err := getSecretsFromOptions(opts)
 	if err != nil {
-		return fmt.Errorf("did not understand secret body: %w", err)
+		return err
 	}
 
 	c, err := opts.HttpClient()
@@ -155,23 +173,42 @@ func setRun(opts *SetOptions) error {
 	orgName := opts.OrgName
 	envName := opts.EnvName
 
+	var host string
 	var baseRepo ghrepo.Interface
 	if orgName == "" && !opts.UserSecrets {
 		baseRepo, err = opts.BaseRepo()
 		if err != nil {
 			return fmt.Errorf("could not determine base repo: %w", err)
 		}
+		host = baseRepo.RepoHost()
+	} else {
+		cfg, err := opts.Config()
+		if err != nil {
+			return err
+		}
+
+		host, err = cfg.DefaultHost()
+		if err != nil {
+			return err
+		}
 	}
 
-	cfg, err := opts.Config()
-	if err != nil {
-		return err
-	}
-
-	host, err := cfg.DefaultHost()
-	if err != nil {
-		return err
+	type repoNamesResult struct {
+		ids []int64
+		err error
 	}
+	repoNamesC := make(chan repoNamesResult, 1)
+	go func() {
+		if len(opts.RepositoryNames) == 0 {
+			repoNamesC <- repoNamesResult{}
+			return
+		}
+		repositoryIDs, err := mapRepoNamesToIDs(client, host, opts.OrgName, opts.RepositoryNames)
+		repoNamesC <- repoNamesResult{
+			ids: repositoryIDs,
+			err: err,
+		}
+	}()
 
 	var pk *PubKey
 	if orgName != "" {
@@ -187,63 +224,179 @@ func setRun(opts *SetOptions) error {
 		return fmt.Errorf("failed to fetch public key: %w", err)
 	}
 
-	eBody, err := box.SealAnonymous(nil, body, &pk.Raw, opts.RandomOverride)
-	if err != nil {
-		return fmt.Errorf("failed to encrypt body: %w", err)
-	}
-
-	encoded := base64.StdEncoding.EncodeToString(eBody)
-	if opts.DoNotStore {
-		_, err := fmt.Fprintln(opts.IO.Out, encoded)
-		return err
-	}
-
-	if orgName != "" {
-		err = putOrgSecret(client, host, pk, *opts, encoded)
-	} else if envName != "" {
-		err = putEnvSecret(client, pk, baseRepo, envName, opts.SecretName, encoded)
-	} else if opts.UserSecrets {
-		err = putUserSecret(client, host, pk, *opts, encoded)
+	var repositoryIDs []int64
+	if result := <-repoNamesC; result.err == nil {
+		repositoryIDs = result.ids
 	} else {
-		err = putRepoSecret(client, pk, baseRepo, opts.SecretName, encoded)
-	}
-	if err != nil {
-		return fmt.Errorf("failed to set secret: %w", err)
+		return result.err
 	}
 
-	if opts.IO.IsStdoutTTY() {
+	setc := make(chan setResult)
+	for secretKey, secret := range secrets {
+		key := secretKey
+		value := secret
+		go func() {
+			setc <- setSecret(opts, pk, host, client, baseRepo, key, value, repositoryIDs)
+		}()
+	}
+
+	err = nil
+	cs := opts.IO.ColorScheme()
+	for i := 0; i < len(secrets); i++ {
+		result := <-setc
+		if result.err != nil {
+			err = multierror.Append(err, result.err)
+			continue
+		}
+		if result.encrypted != "" {
+			fmt.Fprintln(opts.IO.Out, result.encrypted)
+			continue
+		}
+		if !opts.IO.IsStdoutTTY() {
+			continue
+		}
 		target := orgName
 		if opts.UserSecrets {
 			target = "your user"
 		} else if orgName == "" {
 			target = ghrepo.FullName(baseRepo)
 		}
-		cs := opts.IO.ColorScheme()
-		fmt.Fprintf(opts.IO.Out, "%s Set secret %s for %s\n", cs.SuccessIconWithColor(cs.Green), opts.SecretName, target)
+		fmt.Fprintf(opts.IO.Out, "%s Set secret %s for %s\n", cs.SuccessIcon(), result.key, target)
+	}
+	return err
+}
+
+type setResult struct {
+	key       string
+	encrypted string
+	err       error
+}
+
+func setSecret(opts *SetOptions, pk *PubKey, host string, client *api.Client, baseRepo ghrepo.Interface, secretKey string, secret []byte, repositoryIDs []int64) (res setResult) {
+	orgName := opts.OrgName
+	envName := opts.EnvName
+	res.key = secretKey
+
+	decodedPubKey, err := base64.StdEncoding.DecodeString(pk.Key)
+	if err != nil {
+		res.err = fmt.Errorf("failed to decode public key: %w", err)
+		return
+	}
+	var peersPubKey [32]byte
+	copy(peersPubKey[:], decodedPubKey[0:32])
+
+	var rand io.Reader
+	if opts.RandomOverride != nil {
+		rand = opts.RandomOverride()
+	}
+	eBody, err := box.SealAnonymous(nil, secret[:], &peersPubKey, rand)
+	if err != nil {
+		res.err = fmt.Errorf("failed to encrypt body: %w", err)
+		return
 	}
 
-	return nil
+	encoded := base64.StdEncoding.EncodeToString(eBody)
+	if opts.DoNotStore {
+		res.encrypted = encoded
+		return
+	}
+
+	if orgName != "" {
+		err = putOrgSecret(client, host, pk, opts.OrgName, opts.Visibility, secretKey, encoded, repositoryIDs)
+	} else if envName != "" {
+		err = putEnvSecret(client, pk, baseRepo, envName, secretKey, encoded)
+	} else if opts.UserSecrets {
+		err = putUserSecret(client, host, pk, secretKey, encoded, repositoryIDs)
+	} else {
+		err = putRepoSecret(client, pk, baseRepo, secretKey, encoded)
+	}
+	if err != nil {
+		res.err = fmt.Errorf("failed to set secret %q: %w", secretKey, err)
+		return
+	}
+	return
+}
+
+func getSecretsFromOptions(opts *SetOptions) (map[string][]byte, error) {
+	secrets := make(map[string][]byte)
+
+	if opts.EnvFile != "" {
+		var r io.Reader
+		if opts.EnvFile == "-" {
+			defer opts.IO.In.Close()
+			r = opts.IO.In
+		} else {
+			f, err := os.Open(opts.EnvFile)
+			if err != nil {
+				return nil, fmt.Errorf("failed to open env file: %w", err)
+			}
+			defer f.Close()
+			r = f
+		}
+		envs, err := godotenv.Parse(r)
+		if err != nil {
+			return nil, fmt.Errorf("error parsing env file: %w", err)
+		}
+		if len(envs) == 0 {
+			return nil, fmt.Errorf("no secrets found in file")
+		}
+		for key, value := range envs {
+			secrets[key] = []byte(value)
+		}
+		return secrets, nil
+	}
+
+	body, err := getBody(opts)
+	if err != nil {
+		return nil, fmt.Errorf("did not understand secret body: %w", err)
+	}
+	secrets[opts.SecretName] = body
+	return secrets, nil
 }
 
 func getBody(opts *SetOptions) ([]byte, error) {
-	if opts.Body == "" {
-		if opts.IO.CanPrompt() {
-			err := prompt.SurveyAskOne(&survey.Password{
-				Message: "Paste your secret",
-			}, &opts.Body)
-			if err != nil {
-				return nil, err
-			}
-			fmt.Fprintln(opts.IO.Out)
-		} else {
-			body, err := ioutil.ReadAll(opts.IO.In)
-			if err != nil {
-				return nil, fmt.Errorf("failed to read from STDIN: %w", err)
-			}
-
-			return body, nil
-		}
+	if opts.Body != "" {
+		return []byte(opts.Body), nil
 	}
 
-	return []byte(opts.Body), nil
+	if opts.IO.CanPrompt() {
+		var bodyInput string
+		err := prompt.SurveyAskOne(&survey.Password{
+			Message: "Paste your secret",
+		}, &bodyInput)
+		if err != nil {
+			return nil, err
+		}
+		fmt.Fprintln(opts.IO.Out)
+		return []byte(bodyInput), nil
+	}
+
+	body, err := ioutil.ReadAll(opts.IO.In)
+	if err != nil {
+		return nil, fmt.Errorf("failed to read from standard input: %w", err)
+	}
+
+	return bytes.TrimRight(body, "\r\n"), nil
+}
+
+func mapRepoNamesToIDs(client *api.Client, host, defaultOwner string, repositoryNames []string) ([]int64, error) {
+	repos := make([]ghrepo.Interface, 0, len(repositoryNames))
+	for _, repositoryName := range repositoryNames {
+		var repo ghrepo.Interface
+		if strings.Contains(repositoryName, "/") || defaultOwner == "" {
+			var err error
+			repo, err = ghrepo.FromFullNameWithHost(repositoryName, host)
+			if err != nil {
+				return nil, fmt.Errorf("invalid repository name: %w", err)
+			}
+		} else {
+			repo = ghrepo.NewWithHost(defaultOwner, repositoryName, host)
+		}
+		repos = append(repos, repo)
+	}
+	repositoryIDs, err := mapRepoToID(client, host, repos)
+	if err != nil {
+		return nil, fmt.Errorf("failed to look up IDs for repositories %v: %w", repositoryNames, err)
+	}
+	return repositoryIDs, nil
 }
